@@ -4,11 +4,7 @@ context("parser")
 test_that("yq/qy work as expected", {
 
   x <- c("dfw2018q2", "bl2017qasdg4sadgfas", "201712", "blubb", "2017-2016", NA)
-
-  expect_warning(
-    r <- as.integer(yq(x)),
-    "3 failed"
-  )
+  expect_warning(r <- as.integer(yq(x)), "3 failed")
 
   expect_identical(
     r,
@@ -18,16 +14,15 @@ test_that("yq/qy work as expected", {
 
   x <- c("d2fw2018", "b4l2017", "122017", "blubb", "2017-2016", NA)
 
-  expect_warning(
-    r <- as.integer(qy(x)),
-    "3 failed"
-  )
+  expect_warning(r <- as.integer(qy(x)), "3 failed")
 
   expect_identical(
     r,
     c(20182L, 20174L, NA_integer_, NA_integer_, NA_integer_, NA_integer_)
   )
 
+  expect_identical(qy("stpQ42015"), dint::date_yq(2015, 4))
+  expect_identical(yq("stp20154"), dint::date_yq(2015, 4))
 })
 
 
@@ -61,4 +56,6 @@ test_that("ym/my work as expected", {
     c(201802L, 201712L, NA_integer_, NA_integer_, NA_integer_, NA_integer_)
   )
 
+  expect_identical(my("stpm042015"), dint::date_ym(2015, 4))
+  expect_identical(ym("stpm201504"), dint::date_ym(2015, 4))
 })
